<?php 

session_start();
ob_start();

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

require 'PHPMailer/src/Exception.php';
require 'PHPMailer/src/PHPMailer.php';
require 'PHPMailer/src/SMTP.php';

include 'config/init.php';

if (isset($_SESSION['AUTH_SESSION']) && isset($_SESSION['USER_SESSION']) ) {
	if (isset($_GET['user']) && isset($_GET['token']) && isset($_GET['action']) && isset($_GET['payment'])) {

		$val = htmlspecialchars(trim($_GET['user']));
		$realtor = htmlspecialchars(trim(hex2bin($_GET['token'])));
		$action = htmlspecialchars(trim($_GET['action']));
		$payment = htmlspecialchars(trim(hex2bin($_GET['payment'])));

		$select = $pdo->prepare("SELECT * FROM realtors WHERE validation = :auth AND realtor_id = :realtor_id");
		$select->execute(['auth' => $val, 'realtor_id' => $realtor]);
		$count = $select->rowCount();
		if ($count == 0) {
			flash("error", "No Realtor found!");
			header("Location: auth/login");
		} else {
			$row = $select->fetch(PDO::FETCH_ASSOC);

			$status = ucfirst($action);
			$username = $row['username'];
			$email = $row['email'];

			if ($status == 'Confirmed') {
				$msg = 'Congratulations, your transaction with ID - '.$payment.' has been Confirmed';
			} else {
				$msg = 'Sorry, your transaction with ID - '.$payment.' has been Rejected, please contact the administrator for more information';
			}

			if ($row['realtor_id'] !== $realtor || $val !== $row['validation']) {
				flash("error", "Code Verification failed");
				$_SESSION['msg'] = '
					<div class="alert alert-dismissible alert-custom alert-outline-danger fade show mb-5" role="alert">
						<div class="alert-icon"><i class="bi bi-exclamation-triangle"></i></div>
						<div class="alert-text">Code/Token Verification failed!</div>
						<div class="alert-close">
							<button type="button" class="close position-absolute position-sm-relative m-2 m-sm-0 top-0 end-0 btn btn-icon ms-sm-auto" data-bs-dismiss="alert" aria-label="Close">
								<span aria-hidden="true"><i class="bi bi-x fs-1"></i></span>
							</button>
						</div>
					</div>
				';
				header("Location: auth/login");
			} else {
				$update = $pdo->query("UPDATE transactions SET status = '$status' WHERE realtor_id = '{$row['realtor_id']}' AND transaction_id = '$payment'");

				// ============================= //
                //          User Mail        //
                // ============================= //

                // set the location of the template file to be loaded
                $template_file = "includes/payment-status-template.php";

                // set the email 'from' information
                $email_from = SITE_NAME ."<" . SITE_EMAIL . ">";

                // create a list of the variables to be swapped in the html template
                $swap_var = array(
                    "{SITE_ADDR}" => BASE_URL,
                    "{EMAIL_LOGO}" => SITE_LOGO,
                    "{SITE_NAME}" => SITE_NAME,
                    "{EMAIL_TITLE}" => "Transaction Payment ".$status,
                    "{TO_NAME}" => "$username",
                    "{STATUS}" => "$status",
                    "{MSG}" => "$msg",
                    "{TO_EMAIL}" => "$email"
                );

                // create the email headers to being the email
                $email_headers = "From: ".$email_from."\r\nReply-To: ".$email_from."\r\n";
                $email_headers .= "MIME-Version: 1.0\r\n";
                $email_headers .= "Return-Path: ".$email_from."\r\n";
                $email_headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";

                // load the email to and subject from the $swap_var
                $email_to = $swap_var['{TO_EMAIL}'];
                $email_subject = $swap_var['{EMAIL_TITLE}']; // you can add time() to get unique subjects for testing: time();

                // load in the template file for processing (after we make sure it exists)
                if (file_exists($template_file))
                    $email_message = file_get_contents($template_file);
                else
                    die ("Unable to locate your template file");

                // search and replace for predefined variables, like SITE_ADDR, {NAME}, {lOGO}, {CUSTOM_URL} etc
                foreach (array_keys($swap_var) as $key){
                    if (strlen($key) > 2 && trim($swap_var[$key]) != '')
                        $email_message = str_replace($key, $swap_var[$key], $email_message);
                }

                $mail = new PHPMailer(true);
                $mail->isSMTP();
                $mail->Host = MAIL_HOST;
                $mail->SMTPAuth = true;
                $mail->Username = SITE_EMAIL;
                $mail->Password = EMAIL_PASSWORD;
                $mail->Port = 465;
                $mail->SMTPSecure = 'ssl';
                $mail->isHTML(true);
                $mail->setFrom(SITE_EMAIL, SITE_NAME);
                $mail->addAddress($email_to);
                $mail->Subject = ("$email_subject");
                $mail->Body = $email_message;
	                
                if ($update && $mail->send()) {
                	flash("success", "Success, user transactions updated!");
                    $_SESSION['msg'] = '
                        <div class="alert alert-dismissible alert-custom alert-outline-success fade show mb-5" role="alert">
                            <div class="alert-icon"><i class="bi bi-hand-thumbs-up"></i></div>
                            <div class="alert-text">Success, user transactions updated!</div>
                            <div class="alert-cslose">
                                <button type="button" class="close position-absolute position-sm-relative m-2 m-sm-0 top-0 end-0 btn btn-icon ms-sm-auto" data-bs-dismiss="alert" aria-label="Close">
                                    <span aria-hidden="true"><i class="bi bi-x fs-1"></i></span>
                                </button>
                            </div>
                        </div>
                    ';
                    header("Location: transactions");
                } else {
                	flash("error", "Something went wrong, failed to update transactions status. Try again later!");
                    $_SESSION['msg'] = '
                        <div class="alert alert-dismissible alert-custom alert-outline-danger fade show mb-5" role="alert">
                            <div class="alert-icon"><i class="bi bi-exclamation-triangle"></i></div>
                            <div class="alert-text">Something went wrong, failed to update transaction status. Try again later!</div>
                            <div class="alert-cslose">
                                <button type="button" class="close position-absolute position-sm-relative m-2 m-sm-0 top-0 end-0 btn btn-icon ms-sm-auto" data-bs-dismiss="alert" aria-label="Close">
                                    <span aria-hidden="true"><i class="bi bi-x fs-1"></i></span>
                                </button>
                            </div>
                        </div>
                    ';
                    header("Location: transactions");
                }
			}

		}

	} else {
		flash("error", "Parameters not set!");
		header("Location: transactions");
	}
} else {
	flash("error", "Parameters not set!");
	header("Location: transactions");
}

?>